from flask import jsonify, url_for

from auth.registry_jwt_auth import process_registry_jwt_auth
from endpoints.v2 import v2_bp, require_repo_read
from endpoints.v2.errors import NameUnknown
from endpoints.v2.v2util import add_pagination
from endpoints.decorators import anon_protect
from data import model
from endpoints.common import parse_repository_name

@v2_bp.route('/<repopath:repository>/tags/list', methods=['GET'])
@process_registry_jwt_auth
@parse_repository_name
@require_repo_read
@anon_protect
def list_all_tags(namespace, repo_name):
  repository = model.repository.get_repository(namespace, repo_name)
  if repository is None:
    raise NameUnknown()

  query = model.tag.list_repository_tags(namespace, repo_name)
  url = url_for('v2.list_all_tags', repository='%s/%s' % (namespace, repo_name))
  link, query = add_pagination(query, url)

  response = jsonify({
    'name': '{0}/{1}'.format(namespace, repo_name),
    'tags': [tag.name for tag in query],
  })

  if link is not None:
    response.headers['Link'] = link

  return response
